# Actuarial

import numpy
import numpy as np
import pandas
import pandas as pd
import scipy
import scipy.stats as st
import statsmodels
import statsmodels.api as sm
import statsmodels.formula.api as smf

# And plotting
from fxy.p import *



from setuptools import find_packages, setup

setup(
    name='fxy',
    version='0.1.6',
    description='Convenience imports and scientific functions.',
    url='https://github.com/mindey/fxy',
    author='Mindey',
    author_email='mindey@qq.com',
    license='UNLICENSE',
    packages = find_packages(exclude=['docs', 'tests*']),
    install_requires=[],
    extras_require = {
        'test': ['coverage', 'pytest', 'pytest-cov'],
        'all': ["mpmath", "sympy", "numpy", "pandas", "scipy", "statsmodels", "sklearn", "matplotlib"]
    },
    zip_safe=False
)
